Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Runner ¶
type Runner interface {
// Execute will run the game plan and load all the required services
Execute(plan *types.Plan) error
// Shutdown is an idempotent operation that will
// ensure the stared skirmish will cancel straight away
Shutdown() error
}
Runner defines the operation for the orchestration of chaos
Click to show internal directories.
Click to hide internal directories.